Stan Math Library: stan/math/rev/scal/fun/primitive_value.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

primitive_value.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_PRIMITIVE_VALUE_HPP
2 #define STAN_MATH_REV_SCAL_FUN_PRIMITIVE_VALUE_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/primitive_value.hpp>
6
7 namespace stan {
8 namespace math {
9
17 inline double primitive_value(const var& v) {
18 return v.val();
19 }
20
21 }
22 }
23 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::primitive_value
double primitive_value(const fvar< T > &v)
Return the primitive value of the specified forward-mode autodiff variable.
Definition: primitive_value.hpp:22
primitive_value.hpp
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.